@@ -10,11 +10,12 @@ import re
 import sys
 from collections import ChainMap
 from contextlib import suppress
-from typing import TYPE_CHECKING, Any, BinaryIO, Iterator, Mapping
+from typing import TYPE_CHECKING, Any, BinaryIO, ClassVar, Iterator, Mapping
 
 from griffe.collections import LinesCollection, ModulesCollection
 from griffe.docstrings.parsers import Parser
 from griffe.exceptions import AliasResolutionError
+from griffe.extensions import load_extensions
 from griffe.loader import GriffeLoader
 from griffe.logger import patch_loggers
 from mkdocstrings.extension import PluginError
@@ -24,12 +25,6 @@ from mkdocstrings.loggers import get_logger
 
 from mkdocstrings_handlers.python import rendering
 
-try:
-    from griffe.extensions import load_extensions
-except ImportError:
-    # TODO: remove once support for Griffe 0.25 is dropped
-    from griffe.agents.extensions import load_extensions  # type: ignore[no-redef]
-
 if TYPE_CHECKING:
     from markdown import Markdown
 
@@ -71,8 +66,8 @@ class PythonHandler(BaseHandler):
     domain: str = "py"  # to match Sphinx's default domain
     enable_inventory: bool = True
     fallback_theme = "material"
-    fallback_config: dict = {"fallback": True}
-    default_config: dict = {
+    fallback_config: ClassVar[dict] = {"fallback": True}  # type: ignore[misc]
+    default_config: ClassVar[dict] = {
         "docstring_style": "google",
         "docstring_options": {},
         "show_root_heading": False,
@@ -89,6 +84,9 @@ class PythonHandler(BaseHandler):
         "line_length": 60,
         "merge_init_into_class": False,
         "show_docstring_attributes": True,
+        "show_docstring_functions": True,
+        "show_docstring_classes": True,
+        "show_docstring_modules": True,
         "show_docstring_description": True,
         "show_docstring_examples": True,
         "show_docstring_other_parameters": True,
@@ -106,6 +104,7 @@ class PythonHandler(BaseHandler):
         "members_order": rendering.Order.alphabetical.value,
         "docstring_section_style": "table",
         "members": None,
+        "inherited_members": False,
         "filters": ["!^_[^_]"],
         "annotations_path": "brief",
         "preload_modules": None,
@@ -138,7 +137,13 @@ class PythonHandler(BaseHandler):
         show_category_heading (bool): When grouped by categories, show a heading for each category. Default: `False`.
 
     Attributes: Members options:
-        members (list[str] | False | None): An explicit list of members to render. Default: `None`.
+        inherited_members (list[str] | bool | None): A boolean, or an explicit list of inherited members to render.
+            If true, select all inherited members, which can then be filtered with `members`.
+            If false or empty list, do not select any inherited member. Default: `False`.
+        members (list[str] | bool | None): A boolean, or an explicit list of members to render.
+            If true, select all members without further filtering.
+            If false or empty list, do not render members.
+            If none, select all members and apply further filtering with filters and docstrings. Default: `None`.
         members_order (str): The members ordering to use. Options: `alphabetical` - order by the members names,
             `source` - order members as they appear in the source file. Default: `"alphabetical"`.
         filters (list[str] | None): A list of filters applied to filter objects based on their name.
@@ -155,6 +160,9 @@ class PythonHandler(BaseHandler):
         merge_init_into_class (bool): Whether to merge the `__init__` method into the class' signature and docstring. Default: `False`.
         show_if_no_docstring (bool): Show the object heading even if it has no docstring or children with docstrings. Default: `False`.
         show_docstring_attributes (bool): Whether to display the "Attributes" section in the object's docstring. Default: `True`.
+        show_docstring_functions (bool): Whether to display the "Functions" or "Methods" sections in the object's docstring. Default: `True`.
+        show_docstring_classes (bool): Whether to display the "Classes" section in the object's docstring. Default: `True`.
+        show_docstring_modules (bool): Whether to display the "Modules" section in the object's docstring. Default: `True`.
         show_docstring_description (bool): Whether to display the textual block (including admonitions) in the object's docstring. Default: `True`.
         show_docstring_examples (bool): Whether to display the "Examples" section in the object's docstring. Default: `True`.
         show_docstring_other_parameters (bool): Whether to display the "Other Parameters" section in the object's docstring. Default: `True`.
@@ -180,6 +188,7 @@ class PythonHandler(BaseHandler):
         *args: Any,
         config_file_path: str | None = None,
         paths: list[str] | None = None,
+        locale: str = "en",
         **kwargs: Any,
     ) -> None:
         """Initialize the handler.
@@ -188,6 +197,7 @@ class PythonHandler(BaseHandler):
             *args: Handler name, theme and custom templates.
             config_file_path: The MkDocs configuration file path.
             paths: A list of paths to use as Griffe search paths.
+            locale: The locale to use when rendering content.
             **kwargs: Same thing, but with keyword arguments.
         """
         super().__init__(*args, **kwargs)
@@ -208,6 +218,7 @@ class PythonHandler(BaseHandler):
         self._paths = search_paths
         self._modules_collection: ModulesCollection = ModulesCollection()
         self._lines_collection: LinesCollection = LinesCollection()
+        self._locale = locale
 
     @classmethod
     def load_inventory(
@@ -321,7 +332,13 @@ class PythonHandler(BaseHandler):
         final_config["signature_crossrefs"] = False
 
         return template.render(
-            **{"config": final_config, data.kind.value: data, "heading_level": heading_level, "root": True},
+            **{
+                "config": final_config,
+                data.kind.value: data,
+                "heading_level": heading_level,
+                "root": True,
+                "locale": self._locale,
+            },
         )
 
     def update_env(self, md: Markdown, config: dict) -> None:  # noqa: D102 (ignore missing docstring)
@@ -329,6 +346,7 @@ class PythonHandler(BaseHandler):
         self.env.trim_blocks = True
         self.env.lstrip_blocks = True
         self.env.keep_trailing_newline = False
+        self.env.filters["split_path"] = rendering.do_split_path
         self.env.filters["crossref"] = rendering.do_crossref
         self.env.filters["multi_crossref"] = rendering.do_multi_crossref
         self.env.filters["order_members"] = rendering.do_order_members
@@ -337,6 +355,7 @@ class PythonHandler(BaseHandler):
         self.env.filters["filter_objects"] = rendering.do_filter_objects
         self.env.filters["stash_crossref"] = lambda ref, length: ref
         self.env.filters["get_template"] = rendering.do_get_template
+        self.env.tests["existing_template"] = lambda template_name: template_name in self.env.list_templates()
 
     def get_anchors(self, data: CollectorItem) -> set[str]:  # noqa: D102 (ignore missing docstring)
         try:
@@ -350,6 +369,7 @@ def get_handler(
     custom_templates: str | None = None,
     config_file_path: str | None = None,
     paths: list[str] | None = None,
+    locale: str = "en",
     **config: Any,  # noqa: ARG001
 ) -> PythonHandler:
     """Simply return an instance of `PythonHandler`.
@@ -359,6 +379,7 @@ def get_handler(
         custom_templates: Directory containing custom templates.
         config_file_path: The MkDocs configuration file path.
         paths: A list of paths to use as Griffe search paths.
+        locale: The locale to use when rendering content.
         **config: Configuration passed to the handler.
 
     Returns:
@@ -370,4 +391,5 @@ def get_handler(
         custom_templates=custom_templates,
         config_file_path=config_file_path,
         paths=paths,
+        locale=locale,
     )
